@@ -34,6 +34,7 @@
 
 #if GTK_CHECK_VERSION (3, 0, 0)
 #define gdk_cursor_unref g_object_unref
+#define gtk_hbox_new(X,Y) gtk_box_new(GTK_ORIENTATION_HORIZONTAL,Y)
 #endif
 
 enum {
@@ -527,7 +528,11 @@ ev_view_presentation_update_current_page (EvViewPresentation *pview,
 	if (pview->cursor != EV_VIEW_CURSOR_HIDDEN) {
 		gint x, y;
 
+#if GTK_CHECK_VERSION(3, 0, 0)
+		ev_document_misc_get_pointer_position (GTK_WIDGET (pview), &x, &y);
+#else
 		gtk_widget_get_pointer (GTK_WIDGET (pview), &x, &y);
+#endif
 		ev_view_presentation_set_cursor_for_location (pview, x, y);
 	}
 
@@ -1033,8 +1038,10 @@ ev_view_presentation_draw_end_page (EvViewPresentation *pview, cairo_t *cr)
 	PangoLayout *layout;
 	PangoFontDescription *font_desc;
 	gchar *markup;
+#if !GTK_CHECK_VERSION (3, 0, 0)
 	GtkAllocation allocation;
 	GdkRectangle area = {0};
+#endif
 	const gchar *text = _("End of presentation. Click to exit.");
 
 	if (pview->state != EV_PRESENTATION_END)
@@ -1049,9 +1056,11 @@ ev_view_presentation_draw_end_page (EvViewPresentation *pview, cairo_t *cr)
 	pango_font_description_set_size (font_desc, 16 * PANGO_SCALE);
 	pango_layout_set_font_description (layout, font_desc);
 
+#if !GTK_CHECK_VERSION (3, 0, 0)
 	gtk_widget_get_allocation (widget, &allocation);
 	area.width = allocation.width;
 	area.height = allocation.height;
+#endif
 
 #if GTK_CHECK_VERSION (3, 0, 0)
 	gtk_render_layout (gtk_widget_get_style_context (widget),
@@ -1218,7 +1227,11 @@ ev_view_presentation_key_press_event (GtkWidget   *widget,
 
 		ev_view_presentation_goto_window_create (pview);
 		ev_view_presentation_goto_window_send_key_event (pview, (GdkEvent *)event);
+#if GTK_CHECK_VERSION(3, 0, 0)
+		ev_document_misc_get_pointer_position (GTK_WIDGET (pview), &x, &y);
+#else
 		gtk_widget_get_pointer (GTK_WIDGET (pview), &x, &y);
+#endif
 		gtk_window_move (GTK_WINDOW (pview->goto_window), x, y);
 		gtk_widget_show (pview->goto_window);
 		ev_view_presentation_goto_entry_grab_focus (pview);
@@ -1400,6 +1413,10 @@ ev_view_presentation_scroll_event (GtkWidget      *widget,
 	case GDK_SCROLL_LEFT:
 		ev_view_presentation_change_page (pview, GTK_SCROLL_PAGE_BACKWARD);
 		break;
+#if GTK_CHECK_VERSION (3, 0, 0)
+        case GDK_SCROLL_SMOOTH:
+                return FALSE;
+#endif
 	}
 
 	return TRUE;
@@ -1494,9 +1511,6 @@ ev_view_presentation_class_init (EvViewPresentationClass *klass)
 	GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
 	GObjectClass   *gobject_class = G_OBJECT_CLASS (klass);
 	GtkBindingSet  *binding_set;
-#if GTK_CHECK_VERSION (3, 0, 0)
-	GtkCssProvider *provider;
-#endif
 
 	klass->change_page = ev_view_presentation_change_page;
 
@@ -1614,25 +1628,35 @@ ev_view_presentation_class_init (EvViewPresentationClass *klass)
 	gtk_binding_entry_add_signal (binding_set, GDK_KEY_K, 0,
 				      "change_page", 1,
 				      GTK_TYPE_SCROLL_TYPE, GTK_SCROLL_PAGE_BACKWARD);
-
-#if GTK_CHECK_VERSION (3, 0, 0)
-        provider = gtk_css_provider_new ();
-        gtk_css_provider_load_from_data (provider,
-                                         "EvViewPresentation {\n"
-                                         " background-color: black; }",
-                                         -1, NULL);
-        gtk_style_context_add_provider_for_screen (gdk_screen_get_default (),
-                                                   GTK_STYLE_PROVIDER (provider),
-                                                   GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
-        g_object_unref (provider);
-#endif
 }
 
 static void
 ev_view_presentation_init (EvViewPresentation *pview)
 {
+#if GTK_CHECK_VERSION (3, 0, 0)
+	static gsize initialization_value = 0;
+
+	gtk_widget_set_can_focus (GTK_WIDGET (pview), TRUE);
+         pview->is_constructing = TRUE;
+
+	if (g_once_init_enter (&initialization_value)) {
+		GtkCssProvider *provider;
+
+		provider = gtk_css_provider_new ();
+		gtk_css_provider_load_from_data (provider,
+						 "EvViewPresentation {\n"
+						 " background-color: black; }",
+						 -1, NULL);
+		gtk_style_context_add_provider_for_screen (gdk_screen_get_default (),
+							   GTK_STYLE_PROVIDER (provider),
+							   GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
+		g_object_unref (provider);
+		g_once_init_leave (&initialization_value, 1);
+	}
+#else
 	gtk_widget_set_can_focus (GTK_WIDGET (pview), TRUE);
         pview->is_constructing = TRUE;
+#endif
 }
 
 GtkWidget *
