@@ -103,12 +103,20 @@ typedef enum {
 
 typedef struct _EvHeightToPageCache {
 	gint rotation;
+	gboolean dual_even_left;
 	gdouble *height_to_page;
 	gdouble *dual_height_to_page;
 } EvHeightToPageCache;
 
 struct _EvView {
+#if GTK_CHECK_VERSION (3, 0, 0)
+	GtkContainer layout;
+
+	/* Container */
+	GList *children;
+#else
 	GtkLayout layout;
+#endif
 
 	EvDocument *document;
 
@@ -159,6 +167,7 @@ struct _EvView {
 	gboolean loading;
 	gboolean continuous;
 	gboolean dual_page;
+	gboolean dual_even_left;
 	gboolean fullscreen;
 	EvSizingMode sizing_mode;
 	GtkWidget *loading_window;
@@ -202,7 +211,11 @@ struct _EvView {
 };
 
 struct _EvViewClass {
+#if GTK_CHECK_VERSION (3, 0, 0)
+	GtkContainerClass parent_class;
+#else
 	GtkLayoutClass parent_class;
+#endif
 
 	void    (*binding_activated)	  (EvView         *view,
 					   GtkScrollType   scroll,
