@@ -29,6 +29,10 @@
 
 #include "ev-previewer-window.h"
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+#define gtk_vbox_new(X,Y) gtk_box_new(GTK_ORIENTATION_VERTICAL,Y)
+#endif
+
 struct _EvPreviewerWindow {
 	GtkWindow         base_instance;
 
@@ -294,6 +298,7 @@ static const GtkActionEntry action_entries[] = {
           N_("Shrink the document"),
           G_CALLBACK (ev_previewer_window_zoom_out) },
 #if GTKUNIXPRINT_ENABLED
+	/* translators: Print document currently shown in the Print Preview window */
 	{ "PreviewPrint", GTK_STOCK_PRINT, N_("Print"), NULL,
 	  N_("Print this document"),
 	  G_CALLBACK (ev_previewer_window_print) }
