@@ -30,6 +30,11 @@
 #include "ev-keyring.h"
 #include "ev-password-view.h"
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+#define gtk_hbox_new(X,Y) gtk_box_new(GTK_ORIENTATION_HORIZONTAL,Y)
+#define gtk_vbox_new(X,Y) gtk_box_new(GTK_ORIENTATION_VERTICAL,Y)
+#endif
+
 enum {
 	UNLOCK,
 	LAST_SIGNAL
@@ -115,8 +120,10 @@ ev_password_view_init (EvPasswordView *password_view)
 	password_view->priv = EV_PASSWORD_VIEW_GET_PRIVATE (password_view);
 
 	password_view->priv->password_save = G_PASSWORD_SAVE_NEVER;
-	
+
+#if !GTK_CHECK_VERSION(3,0,0)
 	gtk_widget_push_composite_child ();
+#endif
 
 	/* set ourselves up */
 	align = gtk_alignment_new (0.5, 0.5, 0.0, 0.0);
@@ -153,7 +160,9 @@ ev_password_view_init (EvPasswordView *password_view)
 	gtk_box_pack_end (GTK_BOX (hbox), button, FALSE, FALSE, 0);
 
 	gtk_widget_show_all (align);
+#if !GTK_CHECK_VERSION(3,0,0)
 	gtk_widget_pop_composite_child ();
+#endif
 }
 
 /* Public functions */
@@ -242,9 +251,13 @@ ev_password_view_ask_password (EvPasswordView *password_view)
 	GtkWidget *content_area, *action_area;
 	GtkWidget *entry_container;
 	GtkWidget *hbox, *main_vbox, *vbox, *icon;
+#if GTK_CHECK_VERSION (3, 0, 0)
+	GtkWidget *grid;
+#else
 	GtkWidget *table;
+#endif
 	GtkWidget *label;
-	gchar     *format, *markup, *file_name;
+	gchar     *text, *markup, *file_name;
 
 	gtk_widget_set_sensitive (GTK_WIDGET (password_view), FALSE);
 	
@@ -271,10 +284,12 @@ ev_password_view_ask_password (EvPasswordView *password_view)
 	gtk_dialog_set_default_response (dialog, GTK_RESPONSE_OK);
 	gtk_dialog_set_response_sensitive (GTK_DIALOG (dialog),
 					   GTK_RESPONSE_OK, FALSE);
+#if !GTK_CHECK_VERSION(3,0,0)
 	gtk_dialog_set_alternative_button_order (dialog,
 						 GTK_RESPONSE_OK,
 						 GTK_RESPONSE_CANCEL,
 						 -1);
+#endif
 	
 	/* Build contents */
 	hbox = gtk_hbox_new (FALSE, 12);
@@ -297,12 +312,13 @@ ev_password_view_ask_password (EvPasswordView *password_view)
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 	gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
 	file_name = g_file_get_basename (password_view->priv->uri_file);
-	format = g_strdup_printf ("<span size=\"larger\" weight=\"bold\">%s</span>\n\n%s",
+	text = g_markup_printf_escaped (_("The document “%s” is locked and requires a password before it can be opened."),
+                                        file_name);
+	markup = g_strdup_printf ("<span size=\"larger\" weight=\"bold\">%s</span>\n\n%s",
 				  _("Password required"),
-				  _("The document “%s” is locked and requires a password before it can be opened."));
-	markup = g_markup_printf_escaped (format, file_name);
+                                  text);
 	gtk_label_set_markup (GTK_LABEL (label), markup);
-	g_free (format);
+	g_free (text);
 	g_free (markup);
 	g_free (file_name);
 	gtk_box_pack_start (GTK_BOX (main_vbox), label,
@@ -323,11 +339,19 @@ ev_password_view_ask_password (EvPasswordView *password_view)
 			    FALSE, FALSE, 0);
 	gtk_widget_show (entry_container);
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+	grid = gtk_grid_new ();
+	gtk_grid_set_column_spacing (GTK_GRID (grid), 12);
+	gtk_grid_set_row_spacing (GTK_GRID (grid), 6);
+	gtk_container_add (GTK_CONTAINER (entry_container), grid);
+	gtk_widget_show (grid);
+#else
 	table = gtk_table_new (1, 2, FALSE);
 	gtk_table_set_col_spacings (GTK_TABLE (table), 12);
 	gtk_table_set_row_spacings (GTK_TABLE (table), 6);
 	gtk_container_add (GTK_CONTAINER (entry_container), table);
 	gtk_widget_show (table);
+#endif
 
 	label = gtk_label_new_with_mnemonic (_("_Password:"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
@@ -340,6 +364,13 @@ ev_password_view_ask_password (EvPasswordView *password_view)
 	g_signal_connect (password_view->priv->password_entry, "activate",
 			  G_CALLBACK (ev_password_dialog_entry_activated_cb),
 			  dialog);
+#if GTK_CHECK_VERSION (3, 0, 0)
+	gtk_grid_attach (GTK_GRID (grid), label, 0, 0, 1, 1);
+	gtk_widget_show (label);
+
+	gtk_grid_attach (GTK_GRID (grid), password_view->priv->password_entry, 1, 0, 1, 1);
+	gtk_widget_set_hexpand (password_view->priv->password_entry, TRUE);
+#else
 	gtk_table_attach (GTK_TABLE (table), label,
 			  0, 1, 0, 1,
 			  GTK_FILL, GTK_EXPAND | GTK_FILL, 0, 0);	
@@ -347,6 +378,7 @@ ev_password_view_ask_password (EvPasswordView *password_view)
 
 	gtk_table_attach_defaults (GTK_TABLE (table), password_view->priv->password_entry,
 				   1, 2, 0, 1);
+#endif
 	gtk_widget_show (password_view->priv->password_entry);
 	
 	gtk_label_set_mnemonic_widget (GTK_LABEL (label),
